<?php

/**
 * @file
 * Contain list of helpers for the module.
 */

/**
 * Add one more record about user activity.
 *
 * @param int $uid
 * @param int $id
 * @param int $type
 *
 * @return bool|int
 */
function acal_collate($uid, $id, $type) {
  $record = [
    'uid' => $uid,
    'id' => $id,
    'type' => $type,
    'date' => acal_date(),
  ];
  return drupal_write_record('acal', $record);
}

/**
 * Generates current date of needed format.
 *
 * @return false|string
 *   Date like `20171121`.
 */
function acal_date() {
  return date('Ymd');
}

/**
 * Convert date, saved in db and return in format like '2017-11-21'.
 *
 * @param string|int $date
 *
 * @return string
 */
function acal_convert_date($date) {
  return mb_substr($date, 0, 4) . '-' . mb_substr($date, 4, 2) . '-' . mb_substr($date, 6, 2);
}

/**
 * Returns id of passed entity.
 *
 * @param object $entity
 * @param string $type
 *
 * @return null|int
 *   Entity id.
 */
function acal_get_id($entity, $type) {
  $id = NULL;
  switch (TRUE) {

    // Comment.
    case $type == 'comment':
      $id = $entity->cid;
      break;

    // Node.
    case $type == 'node':
      $id = $entity->nid;
      break;
  }
  return $id;
}

/**
 * Returns converted entity.
 *
 * @param string|int $type
 *
 * @return bool|string|int
 */
function acal_type_convert($type) {
  $types = [
    'node' => ACAL_NODE,
    'comment' => ACAL_COMMENT,
    ACAL_NODE => 'node',
    ACAL_COMMENT => 'comment',
  ];
  return isset($types[$type]) ? $types[$type] : FALSE;
}
